@@ -15,6 +15,8 @@ AlbumView::AlbumView(Spotify::Session* pSession, QWidget *pParent)
 
     m_CallerID = ALBUMVIEW_ID;
 
+    m_lastTimeTrackActivated.start();
+
     m_pSession = pSession; //set Spotify session instance pointer
 
     m_pAlbumCoverContainer = new Spotify::ImageContainer(this); //allocate coverart imagecontainer instance
@@ -23,6 +25,7 @@ AlbumView::AlbumView(Spotify::Session* pSession, QWidget *pParent)
     connect(m_pAlbumCoverContainer,SIGNAL(loaded()),SLOT(OnAlbumCoverLoaded()));
     connect(m_pSession,SIGNAL(albumBrowserReady(Spotify::AlbumBrowser*,qint32)),SLOT(OnAlbumBrowserReady(Spotify::AlbumBrowser*,qint32)));
     connect(&m_AlbumReviewBtn,SIGNAL(clicked()),SLOT(OnAlbumReviewBtn()));
+    connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
 
     m_pAlbumTrackView = new QListView(this);
     m_pAlbumTrackDelegate = new ListViewDelegate(this);
@@ -53,12 +56,22 @@ AlbumView::AlbumView(Spotify::Session* pSession, QWidget *pParent)
     m_LeftSubLayout.addWidget(&m_ArtistViewBtn);
     m_LeftSubLayout.setSpacing(10);
 
-    m_MainLayout.addLayout(&m_LeftSubLayout,0,0,3,1);
-    m_MainLayout.addWidget(&m_AlbumCaption,0,1,1,1);
-    m_MainLayout.addWidget(&m_AlbumReviewBtn,1,1,1,1);
-    m_MainLayout.addWidget(m_pAlbumTrackView,2,1,1,1);
+    m_pGridLayoutHoriz = new QGridLayout();
 
-    setLayout(&m_MainLayout);
+    m_pGridLayoutHoriz->addLayout(&m_LeftSubLayout,0,0,3,1);
+    m_pGridLayoutHoriz->addWidget(&m_AlbumCaption,0,1,1,1);
+    m_pGridLayoutHoriz->addWidget(&m_AlbumReviewBtn,1,1,1,1);
+    m_pGridLayoutHoriz->addWidget(m_pAlbumTrackView,2,1,1,1);
+
+    m_pGridLayoutVert = new QGridLayout();
+
+    m_MainLayoutHoriz.setLayout(m_pGridLayoutHoriz);
+    m_MainLayoutVert.setLayout(m_pGridLayoutVert);
+
+    m_MainLayout.addWidget(&m_MainLayoutHoriz); //assign landscape mode layout
+    m_MainLayout.addWidget(&m_MainLayoutVert); //assign portrait mode layout
+
+    setLayout(&m_MainLayout); //set dialog active layout
 }
 
 AlbumView::~AlbumView()
@@ -204,15 +217,18 @@ void AlbumView::OnTrackActivated(QModelIndex trackIndex)
 {
     //A track has been activated (e.g., selected) in the list of album tracks
 
-    if(trackIndex.data(ListViewDelegate::customDataRole).toInt()!=-1)
+    if(m_lastTimeTrackActivated.restart()>=700) //ignore successive (rapid) activations (within 700msecs since last activation)
     {
-        m_pAlbumTrackView->setEnabled(false); //disable listview temporarily
+        if(trackIndex.data(ListViewDelegate::customDataRole).toInt()!=-1)
+        {
+            m_pAlbumTrackView->setEnabled(false); //disable listview temporarily
 
-        setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //show progress indicator
-        emit playQueueSet(m_pAlbumBrowser->getTracks(false),m_pAlbumTrackView->currentIndex().row()); //signal that playqueue has been set / updated
-        hide();
-        setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
-        m_pAlbumTrackView->setEnabled(true); //re-enable the listview
+            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //show progress indicator
+            emit playQueueSet(m_pAlbumBrowser->getTracks(false),m_pAlbumTrackView->currentIndex().row()); //signal that playqueue has been set / updated
+            hide();
+            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+            m_pAlbumTrackView->setEnabled(true); //re-enable the listview
+        }
     }
  }
 
@@ -224,3 +240,63 @@ void AlbumView::OnAlbumCoverLoaded()
     if(m_pAlbumCoverContainer)
         m_AlbumCover.setPixmap(QPixmap::fromImage(m_pAlbumCoverContainer->getImage()).scaled(ALBUMVIEW_COVERART_WIDTH,ALBUMVIEW_COVERART_HEIGHT));
 }
+
+void AlbumView::setReviewDlgOrientation(Qt::WidgetAttribute orientation)
+{
+    //set display orientation for the review dialog instance
+    m_AlbumReviewDlg.setAttribute(orientation);
+}
+
+void AlbumView::OnOrientationChanged()
+{
+    //device orientation changed (e.g, screen rotate)
+
+    QRect screenGeometry = QApplication::desktop()->screenGeometry(); // get current screen geometry
+    if (screenGeometry.width() > screenGeometry.height())
+    {
+        //switch to landscape mode
+        m_pGridLayoutVert->removeWidget(&m_AlbumCover);
+        m_pGridLayoutVert->removeWidget(&m_ArtistViewBtn);
+        m_pGridLayoutVert->removeWidget(&m_AlbumCaption);
+        m_pGridLayoutVert->removeWidget(&m_AlbumReviewBtn);
+        m_pGridLayoutVert->removeWidget(m_pAlbumTrackView);
+
+        m_AlbumCaption.setAlignment(Qt::AlignLeft);
+
+        m_LeftSubLayout.addWidget(&m_AlbumCover);
+        m_LeftSubLayout.addWidget(&m_ArtistViewBtn);
+        m_pGridLayoutHoriz->addWidget(&m_AlbumCaption,0,1,1,1);
+        m_pGridLayoutHoriz->addWidget(&m_AlbumReviewBtn,1,1,1,1);
+        m_pGridLayoutHoriz->addWidget(m_pAlbumTrackView,2,1,1,1);
+
+        setFixedSize(APP_WIDTH,APP_HEIGHT); //resize dialog to fixed size
+
+         m_AlbumReviewDlg.setFixedSize(APP_WIDTH,APP_HEIGHT);
+
+        m_MainLayout.setCurrentIndex(LANDSCAPE_ORIENTATION); //activate landscape layout
+    }
+    else
+    {
+        //switch to portrait mode
+        m_LeftSubLayout.removeWidget(&m_AlbumCover);
+        m_LeftSubLayout.removeWidget(&m_ArtistViewBtn);
+        m_pGridLayoutHoriz->removeWidget(&m_AlbumCaption);
+        m_pGridLayoutHoriz->removeWidget(&m_AlbumReviewBtn);
+        m_pGridLayoutHoriz->removeWidget(m_pAlbumTrackView);
+
+        m_AlbumCaption.setAlignment(Qt::AlignCenter);
+
+        m_pGridLayoutVert->addWidget(&m_AlbumCover,0,0,2,1,Qt::AlignCenter);
+        m_pGridLayoutVert->addWidget(&m_ArtistViewBtn,2,0,1,1,Qt::AlignCenter);
+        m_pGridLayoutVert->addWidget(&m_AlbumCaption,3,0,1,1);
+        m_pGridLayoutVert->addWidget(&m_AlbumReviewBtn,4,0,1,1);
+        m_pGridLayoutVert->addWidget(m_pAlbumTrackView,5,0,1,1);
+
+        setFixedSize(APP_HEIGHT,APP_WIDTH); //resize dialog to fixed size
+
+        m_AlbumReviewDlg.setFixedSize(APP_HEIGHT,APP_WIDTH);
+
+        m_MainLayout.setCurrentIndex(PORTRAIT_ORIENTATION); //activate portrait layout
+
+    }
+}
