@@ -9,19 +9,17 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 
     m_pAppSettings = pSettings;
 
-    setWindowTitle(tr("QSpot - Settings"));
-
-    setFixedSize(800,468);
+    setFixedSize(APP_WIDTH,APP_HEIGHT);
 
     //connect signals/slots
     connect(&m_SaveSettingsBtn,SIGNAL(clicked()),SLOT(OnSaveSettingsBtn()));
     connect(&m_EnableScrobblingSelection,SIGNAL(stateChanged(int)),SLOT(OnScrobblingStateChanged(int)));
+    connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
+
+    setCapsLandscape(); //set caps for landscape mode
 
-    m_maxSearchTracksCaption.setText(tr("Max. tracks returned"));
     m_maxSearchTracksInput.setInputMask("9000");
-    m_maxSearchAlbumsCaption.setText(tr("Max. albums returned"));
     m_maxSearchAlbumsInput.setInputMask("9000");
-    m_maxSearchArtistsCaption.setText(tr("Max. artists returned"));
     m_maxSearchArtistsInput.setInputMask("9000");
 
     m_SearchOptionLayout.addWidget(&m_maxSearchTracksCaption,0,0);
@@ -31,25 +29,34 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_SearchOptionLayout.addWidget(&m_maxSearchArtistsCaption,2,0);
     m_SearchOptionLayout.addWidget(&m_maxSearchArtistsInput,2,1);
 
-    m_SearchOptions.setTitle(tr("Search settings"));
     m_SearchOptions.setLayout(&m_SearchOptionLayout);
 
-    m_MinBufferLenCaption.setText(tr("Min. buffering length (secs)"));
     m_MinBufferLenInput.setInputMask("900");
-    m_PreBufferNextTrackSelection.setText(tr("Enable track pre-buffering"));
 
     m_BufferingOptionLayout.addWidget(&m_MinBufferLenCaption,0,0);
     m_BufferingOptionLayout.addWidget(&m_MinBufferLenInput,0,1);
     m_BufferingOptionLayout.addWidget(&m_PreBufferNextTrackSelection,1,0,1,-1);
 
-    m_BufferingOptions.setTitle(tr("Buffering settings"));
     m_BufferingOptions.setLayout(&m_BufferingOptionLayout);
 
-    m_EnableScrobblingSelection.setText(tr("Enable scrobbling to Last.fm"));
-    m_LastFMUserIDCaption.setText(tr("Last.fm username"));
+    //set up screen orientation value button / selector
+
+    QStringListModel *pListModel = new QStringListModel(this);
+
+    m_orientationList << tr("Landscape") << tr("Portrait") << tr("Automatic");
+
+    pListModel->setStringList(m_orientationList);
+
+    m_pOrientationSelector = new QMaemo5ListPickSelector(this);
+
+    m_pOrientationSelector->setModel(pListModel);
+    m_OrientationBtn.setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered); // Maemo5 style guide wants the menu entries centered.
+    m_OrientationBtn.setPickSelector(m_pOrientationSelector);
+
+    m_PlaylistLoadingTOInput.setInputMask("900");
+
     m_LastFMUserIDInput.setInputMethodHints(Qt::ImhNoAutoUppercase);
-    m_LastFMPasswordCaption.setText(tr("Last.fm password"));
-    m_LastFMPasswordInput.setEchoMode(QLineEdit::Password);
+    m_LastFMPasswordInput.setEchoMode(QLineEdit::Password); //set password mode for input field
 
     m_ScrobblingOptionLayout.addWidget(&m_EnableScrobblingSelection,0,0,1,2);
     m_ScrobblingOptionLayout.addWidget(&m_LastFMUserIDCaption,1,0);
@@ -57,14 +64,18 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_ScrobblingOptionLayout.addWidget(&m_LastFMPasswordCaption,2,0);
     m_ScrobblingOptionLayout.addWidget(&m_LastFMPasswordInput,2,1);
 
-    m_ScrobblingOptions.setTitle(tr("Scrobbling options"));
     m_ScrobblingOptions.setLayout(&m_ScrobblingOptionLayout);
 
-    m_SaveSettingsBtn.setText(tr("Save"));
+    m_PlaylistOptionLayout.addWidget(&m_PlaylistLoadingTOCaption,0,0,1,1);
+    m_PlaylistOptionLayout.addWidget(&m_PlaylistLoadingTOInput,0,1,1,1);
+
+    m_PlaylistOptions.setLayout(&m_PlaylistOptionLayout);
 
     m_GridLayout.addWidget(&m_SearchOptions,0,0,1,-1);
     m_GridLayout.addWidget(&m_BufferingOptions,1,0,1,-1);
-    m_GridLayout.addWidget(&m_ScrobblingOptions,2,0,1,-1);
+    m_GridLayout.addWidget(&m_OrientationBtn,2,0,1,-1);
+    m_GridLayout.addWidget(&m_PlaylistOptions,3,0,1,-1);
+    m_GridLayout.addWidget(&m_ScrobblingOptions,4,0,1,-1);
 
     m_MainAreaLayout.setLayout(&m_GridLayout);
     m_MainArea.setWidget(&m_MainAreaLayout);
@@ -81,6 +92,50 @@ SettingsDialog::~SettingsDialog()
 {
 }
 
+void SettingsDialog::setCapsLandscape()
+{
+    //set dialog captions (landscape mode)
+
+    setWindowTitle(tr("QSpot - Settings"));
+    m_maxSearchTracksCaption.setText(tr("Max. tracks returned"));
+    m_maxSearchAlbumsCaption.setText(tr("Max. albums returned"));
+    m_maxSearchArtistsCaption.setText(tr("Max. artists returned"));
+    m_SearchOptions.setTitle(tr("Search settings"));
+    m_BufferingOptions.setTitle(tr("Buffering settings"));
+    m_MinBufferLenCaption.setText(tr("Min. buffering length (secs)"));
+    m_PreBufferNextTrackSelection.setText(tr("Enable track pre-buffering"));
+    m_OrientationBtn.setText(tr("Display orientation"));
+    m_PlaylistOptions.setTitle(tr("Playlist options"));
+    m_PlaylistLoadingTOCaption.setText(tr("Playlist load timeout (secs)"));
+    m_ScrobblingOptions.setTitle(tr("Scrobbling options"));
+    m_EnableScrobblingSelection.setText(tr("Enable scrobbling to Last.fm"));
+    m_LastFMUserIDCaption.setText(tr("Last.fm username"));
+    m_LastFMPasswordCaption.setText(tr("Last.fm password"));
+    m_SaveSettingsBtn.setText(tr("Save"));
+}
+
+void SettingsDialog::setCapsPortrait()
+{
+    //set dialog captions (portrait mode)
+
+    setWindowTitle(tr("QSpot - Settings"));
+    m_maxSearchTracksCaption.setText(tr("Max. tracks"));
+    m_maxSearchAlbumsCaption.setText(tr("Max. albums"));
+    m_maxSearchArtistsCaption.setText(tr("Max. artists"));
+    m_SearchOptions.setTitle(tr("Search settings"));
+    m_BufferingOptions.setTitle(tr("Buffering settings"));
+    m_MinBufferLenCaption.setText(tr("Min.buff.length (secs)"));
+    m_PreBufferNextTrackSelection.setText(tr("Enable track pre-buff."));
+    m_OrientationBtn.setText(tr("Display orientation"));
+    m_PlaylistOptions.setTitle(tr("Playlist options"));
+    m_PlaylistLoadingTOCaption.setText(tr("Playlist load TO (secs)"));
+    m_ScrobblingOptions.setTitle(tr("Scrobbling options"));
+    m_EnableScrobblingSelection.setText(tr("Enable Last.fm scrobbling"));
+    m_LastFMUserIDCaption.setText(tr("Last.fm username"));
+    m_LastFMPasswordCaption.setText(tr("Last.fm password"));
+    m_SaveSettingsBtn.setText(tr("Save"));
+}
+
 void SettingsDialog::readSettings()
 {
     //read and set current  application settings from config file (if config file not exists, use default settings)
@@ -109,6 +164,13 @@ void SettingsDialog::readSettings()
         else
             m_PreBufferNextTrackSelection.setChecked(false);
 
+        m_currOrientation = m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt();
+
+        m_pOrientationSelector->setCurrentIndex(m_currOrientation);
+
+        m_playlistLoadingTO = m_pAppSettings->value("QSpot/playlistLoadingTO",PLAYLIST_LOADING_TO_DEFAULT).toInt();
+        m_PlaylistLoadingTOInput.setText(QString::number(m_playlistLoadingTO));
+
         m_enableScrobbling = m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt();
 
         if(m_enableScrobbling)
@@ -175,6 +237,18 @@ void SettingsDialog::saveSettings()
             settingsChanged = true;
         }
 
+        if(m_pOrientationSelector->currentIndex()!=m_currOrientation)
+        {
+            m_pAppSettings->setValue("QSpot/displayOrientation",m_pOrientationSelector->currentIndex());
+            settingsChanged = true;
+        }
+
+        if(m_PlaylistLoadingTOInput.text().toInt()!=m_playlistLoadingTO)
+        {
+            m_pAppSettings->setValue("QSpot/playlistLoadingTO",m_PlaylistLoadingTOInput.text().toInt());
+            settingsChanged = true;
+        }
+
         if(m_EnableScrobblingSelection.isChecked())
         {
             m_pAppSettings->setValue("QSpot/enableScrobbling",1);
@@ -222,3 +296,24 @@ void SettingsDialog::OnSaveSettingsBtn()
     saveSettings();
     hide(); //close / hide dialog
 }
+
+void SettingsDialog::OnOrientationChanged()
+{
+    //device orientation changed (e.g, screen rotate)
+
+    QRect screenGeometry = QApplication::desktop()->screenGeometry(); // get current screen geometry
+
+    m_MainLayout.removeWidget(&m_SaveSettingsBtn);
+    if (screenGeometry.width() > screenGeometry.height())
+    {
+        //switch to landscape mode
+        m_MainLayout.addWidget(&m_SaveSettingsBtn,1,1,1,1,Qt::AlignRight);
+        setCapsLandscape();
+    }
+    else
+    {
+        //switch to portrait mode
+         m_MainLayout.addWidget(&m_SaveSettingsBtn,1,0,1,1);
+         setCapsPortrait();
+    }
+}
