@@ -3,6 +3,8 @@
 #ifndef SETTINGSDIALOG_H
 #define SETTINGSDIALOG_H
 
+#include <QApplication>
+#include <QDesktopWidget>
 #include <QDialog>
 #include <QDebug>
 #include <QSettings>
@@ -13,6 +15,12 @@
 #include <QScrollArea>
 #include <QPushButton>
 #include <QGridLayout>
+#include <QStringList>
+#include <QStringListModel>
+#include <QMaemo5ListPickSelector>
+#include <QMaemo5ValueButton>
+#include "global_defs.h"
+
 
 //defines for default setting values
 
@@ -22,6 +30,9 @@
 #define MIN_BUFFER_LEN_DEFAULT  30
 #define PRE_BUFFERING_DEFAULT    1
 #define ENABLE_SCROBBLING_DEFAULT 0
+#define ORIENTATION_DEFAULT 0
+#define PLAYLIST_LOADING_TO_DEFAULT 30
+
 
 class SettingsDialog : public QDialog
 {
@@ -55,6 +66,10 @@ private:
 
     QGridLayout m_BufferingOptionLayout;
 
+    QGroupBox m_PlaylistOptions; //container for playlist related settings
+
+    QGridLayout m_PlaylistOptionLayout;
+
     QGroupBox m_ScrobblingOptions; //container for settings related to Last.fm scrobbling
 
     QGridLayout m_ScrobblingOptionLayout;
@@ -73,13 +88,22 @@ private:
 
     QCheckBox m_PreBufferNextTrackSelection; //selected if automatic buffering of next track should be activated
 
+    QStringList m_orientationList; //list of device orientation values
+
+    QMaemo5ListPickSelector *m_pOrientationSelector; //pick selector associated with the orientation value button
+
+    QMaemo5ValueButton m_OrientationBtn; //value type button for selecting desired screen orientation
+
+    QLabel m_PlaylistLoadingTOCaption;
+    QLineEdit m_PlaylistLoadingTOInput; //timeout value for playlist loading (in secs)
+
     QCheckBox m_EnableScrobblingSelection; //enable / disable scrobbling to Last.Fm
 
     QLabel m_LastFMUserIDCaption;
-    QLineEdit m_LastFMUserIDInput;  //Last.Fm User ID input
+    QLineEdit m_LastFMUserIDInput;  //Last.fm User ID input
 
     QLabel m_LastFMPasswordCaption;
-    QLineEdit m_LastFMPasswordInput;  //Last.Fm password input
+    QLineEdit m_LastFMPasswordInput;  //Last.fm password input
 
     QPushButton m_SaveSettingsBtn; //Save current settings button
 
@@ -95,6 +119,10 @@ private:
 
     qint32 m_preBufferingActive;
 
+    qint32 m_currOrientation;
+
+    qint32 m_playlistLoadingTO;
+
     qint32 m_enableScrobbling;
 
     QString m_strLastFMUserID;
@@ -103,10 +131,14 @@ private:
 
     void saveSettings(); //save (modified) settings
 
+    void setCapsLandscape();
+    void setCapsPortrait();
+
 private slots:
 
     void OnSaveSettingsBtn();
     void OnScrobblingStateChanged(int newState);
+    void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
 
 signals:
 
