@@ -274,7 +274,7 @@ void TrackView::setSearchResults(Spotify::Search* pSearch)
 
         m_pSortByAct->populateListModel(m_SearchSortByList); //populate sorting alternatives
 
-        m_TrackList = pSearch->getTracks();
+        m_TrackList = pSearch->getTracks(false); //only return available tracks
         m_pSortByAct->setCurrentSelection(0); //set sorting to Original order
 	//sort track instance first by artist, then by album, and finally by track
 	qSort(m_TrackList.begin(),m_TrackList.end(),trackLessThanCaseInsensitive); 
@@ -396,6 +396,8 @@ void TrackView::addTracks(const QList<Spotify::Track*>& trackList)
     //add tracks from specified list to main listview.
     //Overriden method.
 
+    qint32 pos = 0;
+
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
 
     m_pTrackListModel->clear();
@@ -405,7 +407,11 @@ void TrackView::addTracks(const QList<Spotify::Track*>& trackList)
          Spotify::Track* currTrack = trackList.at(trackPos);
          if(currTrack)
          {
-           addTrackListModelItem(currTrack,trackPos);
+             if(currTrack->isAvailable())
+             {
+                 addTrackListModelItem(currTrack,pos);
+                 pos++;
+             }
          }
      }
 
