@@ -18,9 +18,10 @@
 #include <qspotify_src/imagecontainer.h>
 #include "ListViewDelegate.h"
 #include "CustomTextDialog.h"
+#include "global_defs.h"
 
-#define ARTIST_PORTRAIT_WIDTH   355
-#define ARTIST_PORTRAIT_HEIGHT  355
+#define ARTIST_PORTRAIT_WIDTH   300
+#define ARTIST_PORTRAIT_HEIGHT  300
 
 class ArtistView : public QDialog
 {
@@ -34,6 +35,8 @@ public:
 
     void setArtist(Spotify::Artist* pArtist); //set current artist
 
+    void setBiographyDlgOrientation(Qt::WidgetAttribute orientation); //set display orientation for the biography dialog instance
+
 private:
 
     QGridLayout *m_pGridLayout; //main view gridlayout
@@ -70,6 +73,7 @@ private slots:
     void OnAlbumActivated(QModelIndex albumIndex);
     void OnArtistBiographyBtn();
     void OnArtistPortraitLoaded();
+    void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
 
 signals:
 
