@@ -6,7 +6,6 @@ MainWindow::MainWindow(QWidget *parent)
 
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow); //window is part of window stack
-   // setAttribute(Qt::WA_Maemo5AutoOrientation);
 #endif
 
     QCoreApplication::setApplicationName("QSpot"); //Setup app name
@@ -14,6 +13,10 @@ MainWindow::MainWindow(QWidget *parent)
 
     setWindowTitle(tr("QSpot - Playlists"));
 
+    m_playing = false;
+
+    m_update = false;
+
     m_pSpectrum = new SpectrumAnalyzer(this,55,40);
     m_pSpectrum->setColor(QColor(255,255,255)); //set spectrum color to white
 
@@ -27,6 +30,12 @@ MainWindow::MainWindow(QWidget *parent)
         m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_STOP); //request to enter initial stopped state
     }
 
+    m_pMCEWrapper = new MCEWrapper(this); //allocate MCE D-bus interface wrapper
+    if(m_pMCEWrapper)
+    {
+        connect(m_pMCEWrapper,SIGNAL(onDisplayStateChange(bool)),SLOT(OnDisplayStateChanged(bool)));
+    }
+
     m_pLastFMScrobbler = new LastFMScrobbler(this); //allocate Last.fm scrobbler instance
     m_pLastFMScrobbler->setAPIKey("f950a6e7870997ea77cb0ecc9c8fb962"); //set associated Last.fm API key
     m_pLastFMScrobbler->setSecret("48875d761d06f7b0efd37304e0226e9f"); //set associated Last.fm shared secret
@@ -62,7 +71,7 @@ MainWindow::MainWindow(QWidget *parent)
     m_pAlbumView = new AlbumView(m_pSession,m_pTrackView);
     connect(m_pAlbumView,SIGNAL(playQueueSet(const QList<Spotify::Track*>&,qint32)),SLOT(OnSetPlayQueue(const QList<Spotify::Track*>&,qint32)));
 
-    m_pQueueView = new QueueView(m_pSession,m_pOssoWrapper,this); //initial parent set to current instance
+    m_pQueueView = new QueueView(m_pSession,m_pOssoWrapper,m_pMCEWrapper,this); //initial parent set to current instance
     connect(m_pQueueView,SIGNAL(playQueuePosUpdated(qint32)),SLOT(OnPlayQueuePosUpdated(qint32)));
     connect(m_pQueueView,SIGNAL(playQueueSet(QList<Spotify::Track*>,qint32)),SLOT(OnSetPlayQueue(QList<Spotify::Track*>,qint32)));
     connect(m_pQueueView,SIGNAL(showFMTransmitterDialog()),SLOT(OnDisplayFMTransmitterDialog()));
@@ -103,6 +112,7 @@ MainWindow::MainWindow(QWidget *parent)
     connect(m_pSpectrum,SIGNAL(clicked()),SLOT(OnNowPlaying()));
     connect(&m_SearchBtn,SIGNAL(clicked()),SLOT(OnSearch()));
     connect(&m_SearchInput,SIGNAL(returnPressed()),SLOT(OnSearch()));
+    connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
 
     m_SearchInput.setInputMethodHints(Qt::ImhNoAutoUppercase); //no auto-uppercase mode
     m_SearchInput.setDisabled(true);
@@ -145,6 +155,8 @@ MainWindow::MainWindow(QWidget *parent)
 
     m_AudioInit = false;
 
+    setDisplayOrientation(m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt()); //set initial display orientation for views / dialogs
+
     emit showLogin(); //emit signal requesting to show login dialog
 }
 
@@ -156,8 +168,9 @@ void MainWindow::initAboutDialog()
 
     m_AboutDlg.setIconPixmap(appIconMap);
     m_AboutDlg.setWindowTitle(tr("About QSpot"));
-    m_AboutDlg.setText(tr("QSpot version ") + APP_VERSION + "\n\n" + tr("An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).\n\n(C) 2010 Andreas Enbacka and The QSpot Team.\n\n"
-                          "Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout."));
+    m_AboutDlg.setText(tr("QSpot version ") + APP_VERSION + "\n\n" + tr("An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).\n\n"
+                        "(C) 2011 Andreas Enbacka and The QSpot Team.\n\n"
+                        "Special thanks to Markus (markusm@tmo) for assistance with the graphicla design and layout."));
 }
 
 MainWindow::~MainWindow()
@@ -176,7 +189,8 @@ void MainWindow::OnDisplayFMTransmitterDialog()
 
 void MainWindow::OnSettingsSaved()
 {
-    //called when app settings have been saved (modified)
+    //called when app settings have been saved (modified)  
+
     m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
 
     if(m_pAppSettings->value("QSpot/preBufferingActive",PRE_BUFFERING_DEFAULT).toInt())
@@ -188,6 +202,8 @@ void MainWindow::OnSettingsSaved()
         m_pSession->setPreBufferingActive(false);
     }
 
+    setDisplayOrientation(m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt());
+
     if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt())
     {
         //scrobbling enabled, send authentication request in order to retrieve a Last.fm session key
@@ -206,8 +222,9 @@ void MainWindow::OnPlayingState(bool state)
     //playback state changed notification from session instance
     if(state)
     { //playing state
-        m_pSpectrum->Start();
         m_playing = true;
+        if(m_update)
+            m_pSpectrum->Start();
     }
     else
     { //paused state
@@ -232,7 +249,7 @@ void MainWindow::OnPlaybackPositionUpdated(qint64 pos)
 
         Spotify::Track* currTrack = m_PlayQueue.at(m_currQueuePos);
 
-        if(currTrack)
+        if(currTrack && m_update)
         {
 
             //set track progress info in format current playback position / total track duration
@@ -292,8 +309,8 @@ void MainWindow::OnShowAlbumView(Spotify::Album* pAlbum)
     //show the Album View for the specified album
     if(sender()==m_pTrackView && m_pQueueView->parent()!=m_pTrackView)
         m_pQueueView->setParent(m_pTrackView,m_pQueueView->windowFlags()); //re-parent the QueueView instance (to TrackView instance)
-    m_pAlbumView->setAlbum(pAlbum);
     m_pAlbumView->showMaximized();
+    m_pAlbumView->setAlbum(pAlbum);
 }
 
 void MainWindow::OnShowArtistView(Spotify::Artist* pArtist)
@@ -305,28 +322,29 @@ void MainWindow::OnShowArtistView(Spotify::Artist* pArtist)
 
 void MainWindow::OnPlayQueuePosUpdated(qint32 pos)
 {
-     if(pos>=0)
-     {
-         m_currQueuePos = pos;
 
-         Spotify::Track* currTrack = m_PlayQueue.at(m_currQueuePos);
+    if(pos>=0)
+    {
+        m_currQueuePos = pos;
 
-         if(currTrack)
-         {
-             m_strNowPlayingInfo = currTrack->getName();
-             if(currTrack->getArtist())
-             {
-                 m_strNowPlayingInfo += ", ";
-                 m_strNowPlayingInfo += currTrack->getArtist()->getName();
-             }
-             m_NowPlayingInfo.setText(m_strNowPlayingInfo);
-         }
-     }
-     else //empty now playing infobar (when playqueue has reached end)
-     {
+        Spotify::Track* currTrack = m_PlayQueue.at(m_currQueuePos);
+
+        if(currTrack)
+        {
+            m_strNowPlayingInfo = currTrack->getName();
+            if(currTrack->getArtist())
+            {
+                m_strNowPlayingInfo += ", ";
+                m_strNowPlayingInfo += currTrack->getArtist()->getName();
+            }
+            m_NowPlayingInfo.setText(m_strNowPlayingInfo);
+        }
+    }
+    else //empty now playing infobar (when playqueue has reached end)
+    {
         m_NowPlayingInfo.setText("----");
         m_NowPlayingPositionInfo.setText("");
-     }
+    }
 }
 
 void MainWindow::logout()
@@ -339,7 +357,7 @@ void MainWindow::logout()
 void MainWindow::OnLoginDialogRejected()
 {
 //request to reject the login dialog, exit app
-   qApp->quit();
+    qApp->quit();
 }
 
 void MainWindow::OnLoggedIn(Spotify::Error error)
@@ -362,7 +380,7 @@ void MainWindow::OnLoggedIn(Spotify::Error error)
     	setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display main window progress indicator
     	m_pLoginDlg->hide();
         m_SearchInput.setFocus(); //set default focus to search field
-        m_pTimeoutTimer->start(PLAYLIST_LOADING_TIMEOUT*1000); //set timeout value
+        m_pTimeoutTimer->start(m_pAppSettings->value("QSpot/playlistLoadingTO",PLAYLIST_LOADING_TO_DEFAULT).toInt()*1000); //set timeout value (in msecs)
     	m_pSession->getPlaylistContainer();
     	QMaemo5InformationBox::information(this,tr("Loading playlists")); //display loading notification
     }
@@ -443,6 +461,45 @@ void MainWindow::setupInitialState()
 
 }
 
+void MainWindow::setDisplayOrientation(qint32 orientation)
+{
+    //set display orientation (e.g., landscape / portrait / automatic mode)
+
+#ifdef Q_WS_MAEMO_5
+    Qt::WidgetAttribute dispOrientation = Qt::WA_Maemo5LandscapeOrientation;
+
+    if(orientation==LANDSCAPE_ORIENTATION)
+        dispOrientation = Qt::WA_Maemo5LandscapeOrientation;
+    else if(orientation==PORTRAIT_ORIENTATION)
+        dispOrientation = Qt::WA_Maemo5PortraitOrientation;
+    else if(orientation==AUTO_ORIENTATION)
+        dispOrientation = Qt::WA_Maemo5AutoOrientation;
+
+    //set display orientation for views / dialogs
+    setAttribute(dispOrientation);
+    if(m_pLoginDlg)
+        m_pLoginDlg->setAttribute(dispOrientation);
+    if(m_pTrackView)
+        m_pTrackView->setAttribute(dispOrientation);
+    if(m_pQueueView)
+        m_pQueueView->setAttribute(dispOrientation);
+    if(m_pSettingsDlg)
+        m_pSettingsDlg->setAttribute(dispOrientation);
+    if(m_pAlbumView)
+    {
+        m_pAlbumView->setAttribute(dispOrientation);
+        m_pAlbumView->setReviewDlgOrientation(dispOrientation);
+    }
+    if(m_pArtistView)
+    {
+        m_pArtistView->setAttribute(dispOrientation);
+        m_pArtistView->setBiographyDlgOrientation(dispOrientation);
+    }
+    m_AboutDlg.setAttribute(dispOrientation);
+
+#endif
+}
+
 void MainWindow::OnPlaylistActivated(QModelIndex index)
 {
 	//Display the trackview for the activated playlist
@@ -511,8 +568,7 @@ void MainWindow::OnSearch()
                 setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
             }
         }
-    }
-}
+    }}
 
 void MainWindow::OnSearchComplete(Spotify::Search* search)
 {
@@ -584,6 +640,38 @@ void MainWindow::OnScrobbleTrack()
         m_pLastFMScrobbler->scrobbleTrack();
 }
 
+void MainWindow::OnOrientationChanged()
+{
+    //device orientation changed (e.g, screen rotate)
 
+    QRect screenGeometry = QApplication::desktop()->screenGeometry(); // get current screen geometry
+    if (screenGeometry.width() > screenGeometry.height())
+    {
+        //switch to landscape mode
+        m_NowPlayingInfo.setFixedWidth(510);
+    }
+    else
+    {
+        //switch to portrait mode
+        m_NowPlayingInfo.setFixedWidth(180);
+    }
+}
 
+void MainWindow::OnDisplayStateChanged(bool state)
+{
+    //Display state changed notification (true=ON, false=OFF)
 
+    if(state)
+    {
+        m_update = true; //allow UI updates
+        //enable spectrum analyzer etc.
+        if(m_playing)
+            m_pSpectrum->Start();
+    }
+    else
+    {
+        m_update = false; //no UI updates
+        //disable spectrum analyzer etc.
+        m_pSpectrum->Stop();
+    }
+}
