@@ -37,8 +37,7 @@ PlaybackThread::PlaybackThread(QObject* parent)
 
     m_pAudioStream = NULL;
 
-    //buffer.maxlength = pa_usec_to_bytes(750000, &ss);
-    buffer.maxlength = -1;
+    buffer.maxlength = pa_usec_to_bytes(750000, &ss); //750ms
     buffer.tlength = -1;
     buffer.prebuf = -1;
     buffer.minreq = -1;
@@ -50,7 +49,7 @@ PlaybackThread::PlaybackThread(QObject* parent)
 
 PlaybackThread::~PlaybackThread()
 {
-    //cleanup
+    //destructor; do cleanup etc.
     int err=0;
     m_audio_mutex.lock(); //lock mutex
     pa_simple_flush(m_pAudioStream,&err); //flush playback buffer
