@@ -24,7 +24,8 @@ Spotify::Session::Session( QObject* parent ):
     m_playlistcontainer( 0 ),
     m_valid( false ),
     m_currentUser( 0 ),
-    m_playbackPos( 0 )
+    m_playbackPos( 0 ),
+    m_bufferedAmount( 0 )
 {
     // Meta types:
     qRegisterMetaType<Spotify::Error>("Spotify::Error");
