@@ -67,14 +67,24 @@ bool Spotify::Track::load()
         // Set availability:
         m_available = sp_track_is_available( m_track );
 
+
         // Set artists:
         if( m_artist == 0 )
         {
             // TODO: loop for all artists..
-            sp_artist* spartist = sp_track_artist( m_track, 0 );
-            m_artist = new Spotify::Artist( spartist );
-            if( !m_artist->isLoaded() )
+            sp_artist* spartist = sp_track_artist( m_track, 0 ); //get first artist
+            if(spartist)
+            {
+                m_artist = new Spotify::Artist( spartist );
+                if( !m_artist->isLoaded() )
+                    return false;
+            }
+            else
+            {
+                //no valid artist associated with the track, set the availability state to false, and return false.
+                m_available = false;
                 return false;
+            }
         }
         else if( !m_artist->isLoaded() )
             if( !m_artist->load() ) return false;
@@ -90,10 +100,12 @@ bool Spotify::Track::load()
         else if( !m_album->isLoaded() )
             if( !m_album->load() ) return false;
 
+
         // Set track name:
         const char* charData = sp_track_name( m_track );
         m_name = QString::fromUtf8( charData, strlen( charData ) );
 
+
         // Set duration
         if( m_duration.second() == 0 )
         {
